@@ -194,6 +194,8 @@ enum aws_common_error {
     AWS_ERROR_INVALID_FILE_HANDLE,
     AWS_ERROR_OPERATION_INTERUPTED,
     AWS_ERROR_DIRECTORY_NOT_EMPTY,
+    AWS_ERROR_PLATFORM_NOT_SUPPORTED,
+    AWS_ERROR_INVALID_UTF8,
     AWS_ERROR_END_COMMON_RANGE = AWS_ERROR_ENUM_END_RANGE(AWS_C_COMMON_PACKAGE_ID)
 };
 
